====================================================
Species decorators
====================================================

This module contains classes and functions to label species charge,
magnetic moment or other site property given a
:class:`pymatgen.entries.ComputedStructureEntry`.

.. toctree::
   :maxdepth: 1

   base
   charge

More to come...
